==> haskell-template-haskell-compat-v0208-0.1.9.4-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.9.4
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.4-7rGQmWjwMsGEImKrvAqQZZ

key:
    template-haskell-compat-v0208-0.1.9.4-7rGQmWjwMsGEImKrvAqQZZ

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    Backward-compatibility layer for Template Haskell newer than 2.8

description:
    Collection of functions that aims to help you to write
    Template Haskell that is compatible
    with all versions of GHC starting from 7.6.
    The oldest GHC serves as the common denominator here,
    so the newer functionality is avoided here.

category:             TemplateHaskell, Compatibility
abi:                  889d4fee955647c43d6f690525ca0743
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/template-haskell-compat-v0208-0.1.9.4

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/template-haskell-compat-v0208-0.1.9.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.4-7rGQmWjwMsGEImKrvAqQZZ

depends:              base-4.16.4.0 template-haskell-2.18.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-template-haskell-compat-v0208-0.1.9.5-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 template-haskell-compat-v0208
version:              0.1.9.5
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.5-63mC43y8xfyDlUsJM0qu2x

key:
    template-haskell-compat-v0208-0.1.9.5-63mC43y8xfyDlUsJM0qu2x

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    Backward-compatibility layer for Template Haskell newer than 2.8

description:
    Collection of functions that aims to help you to write
    Template Haskell that is compatible
    with all versions of GHC starting from 7.6.
    The oldest GHC serves as the common denominator here,
    so the newer functionality is avoided here.

category:             TemplateHaskell, Compatibility
abi:                  9b38d1e4da18991f830cc3cc2b195852
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/template-haskell-compat-v0208-0.1.9.5

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/template-haskell-compat-v0208-0.1.9.5

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/template-haskell-compat-v0208-0.1.9.5

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.5-63mC43y8xfyDlUsJM0qu2x

depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
